@@ -1,4 +1,4 @@
-package Pcore::API::Namecheap v0.5.1;
+package Pcore::API::Namecheap v0.5.2;
 
 use Pcore -dist, -class, -result;
 
@@ -138,7 +138,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
                     }
                 }
 
-                if ( !$api_res ) {
+                if ( !defined $api_res ) {
                     for my $domain ( $hash->{ApiResponse}->{CommandResponse}->[0]->{DomainCheckResult}->@* ) {
                         my $domain_name = $domain->{Domain}->[0]->{content};
 
